# everything2text4prompt

**Background**:

ChatGPT and LLM is an extremely powerful tools for general purpose, but it requires text as input.
Therefore if we can convert many medium (everything) into text, LLM application can be extended to many areas.

**This project is to convert many medium into text, and the text format is specialized for prompt input.**

## Features

- Convert youtube video into text transcript
- Convert podcast into text transcript
- Convert pdf into dense text

## Installation

Install by pypi

```
pip install everything2text4prompt
```

Install by source code

```
pip install -r requirements.txt
```